searchData={"items":[{"type":"module","title":"Distance","doc":"Basic distance calculations for cartesian coordinates for calculting\ndistances on a single plane.  If you are looking to calculating distance\non the surface of Earth, check out the `Distance.GreatCircle` module.","ref":"Distance.html"},{"type":"module","title":"Examples - Distance","doc":"iex> Distance.distance({2.5, 2.5}, {4, 0.8})\n    2.2671568097509267\n    iex> Distance.segment_distance({2.5, 2.5}, {4, 0.8}, {-2, 3})\n    1.0797077632696\n    iex> Distance.distance([{2.5, 2.5}, {4, 0.8}, {-2, 3}, {1, -1}])\n    13.657774933219109","ref":"Distance.html#module-examples"},{"type":"function","title":"Distance.angle_to/2","doc":"Returns the direction from p0 to p1.  The direction is\nmeasured as radians off of the positive x-axis in the direction of the\npositive y-axis.\n\nThe returned value will always be in the range of (-π, π]. The direction \nalong the negative x-axis will always return positive π.","ref":"Distance.html#angle_to/2"},{"type":"function","title":"Examples - Distance.angle_to/2","doc":"iex> Distance.angle_to({2, -1}, {2, 5}) \n    :math.pi() / 2","ref":"Distance.html#angle_to/2-examples"},{"type":"function","title":"Distance.angular_difference/2","doc":"Returns the angular difference between two directions in the range","ref":"Distance.html#angular_difference/2"},{"type":"function","title":"Distance.distance/1","doc":"Returns the geometric distance of the linestring defined by the List of\npoints.  Accepts 2- or 3-dimensional points.","ref":"Distance.html#distance/1"},{"type":"function","title":"Examples - Distance.distance/1","doc":"iex> Distance.distance([{2.5, 2.5}, {4, 0.8}, {2.5, 3.1}, {2.5, 3.1}])\n    5.013062853300123\n    iex> Distance.distance([{1, -2, 1}, {-2, 2, -1}, {-2, 1, 0}, {2, -3, 1}])\n    12.543941016045627","ref":"Distance.html#distance/1-examples"},{"type":"function","title":"Distance.distance/2","doc":"Returns the geometric distance between two points.  Accepts 2- or\n3-dimensional points.","ref":"Distance.html#distance/2"},{"type":"function","title":"Examples - Distance.distance/2","doc":"iex> Distance.distance({1, -2}, {-2, 2})\n    5.0\n    iex> Distance.distance({1, -2, 2}, {-2, 2, 1})\n    5.0990195135927845","ref":"Distance.html#distance/2-examples"},{"type":"function","title":"Distance.distance_squared/2","doc":"Returns the square of the distance between two points.  This is used by the\n`Distance.distance` function above, but having access to the value before\nthe expensice sqaure root operation is useful for time-sensitive applications\nthat only need values for comparison.","ref":"Distance.html#distance_squared/2"},{"type":"function","title":"Examples - Distance.distance_squared/2","doc":"iex> Distance.distance_squared({1, -2}, {-2, 2})\n    25\n    iex> Distance.distance_squared({1, -2, 2}, {-2, 2, 1})\n    26","ref":"Distance.html#distance_squared/2-examples"},{"type":"function","title":"Distance.line_distance/3","doc":"Returns the geometric distance from a point `p` and the infinite line\nextending through points `p1` and `p2`.","ref":"Distance.html#line_distance/3"},{"type":"function","title":"Examples - Distance.line_distance/3","doc":"iex> Distance.line_distance({3, 2}, {-2, 1}, {5, 3})\n    0.4120816918460673 # distance between the point {3, 2} and the closest point along line segment ({-2, 1}, {5, 3})\n    iex> Distance.line_distance({1, -2}, {-2, 2}, {-10, 102})\n    2.671464946476815\n    iex> Distance.line_distance({1, -2}, {-2, 2}, {1, -2})\n    0.0","ref":"Distance.html#line_distance/3-examples"},{"type":"function","title":"Distance.line_distance_squared/3","doc":"Similar to `Distance.distance_squared`, this provides much faster comparable\nversion of `Distance.line_distance`.","ref":"Distance.html#line_distance_squared/3"},{"type":"function","title":"Examples - Distance.line_distance_squared/3","doc":"iex> Distance.line_distance_squared({3, 2}, {-2, 1}, {5, 3})\n    0.16981132075471717\n    iex> Distance.line_distance_squared({1, -2}, {-2, 2}, {-10, 102})\n    7.136724960254371","ref":"Distance.html#line_distance_squared/3-examples"},{"type":"function","title":"Distance.min_coterminal_angle/1","doc":"Returns the cotemrinal angle closest to 0 for the given angle\n\nNo matter the angle provided, the returned angle will be in the range (-π, π]","ref":"Distance.html#min_coterminal_angle/1"},{"type":"function","title":"Examples - Distance.min_coterminal_angle/1","doc":"iex> Distance.min_coterminal_angle(:math.pi() / 2.0)\n    :math.pi() / 2\n    iex> Distance.min_coterminal_angle(-2.0 + :math.pi() * 6)\n    -2.0\n    iex> Distance.min_coterminal_angle(-:math.pi())\n    :math.pi()","ref":"Distance.html#min_coterminal_angle/1-examples"},{"type":"function","title":"Distance.min_positive_coterminal_angle/1","doc":"Returns the minimal positive coterminal angle for the given angle.\n\nNo matter the angle provided, the returned angle will be in the range [0, 2π)","ref":"Distance.html#min_positive_coterminal_angle/1"},{"type":"function","title":"Examples - Distance.min_positive_coterminal_angle/1","doc":"iex> Distance.min_positive_coterminal_angle(:math.pi() / 2.0)\n    :math.pi() / 2\n    iex> Distance.min_positive_coterminal_angle(-2.0 + :math.pi() * 6)\n    :math.pi() * 2.0 - 2.0\n    iex> Distance.min_positive_coterminal_angle(-:math.pi())\n    :math.pi()","ref":"Distance.html#min_positive_coterminal_angle/1-examples"},{"type":"type","title":"Distance.point/0","doc":"","ref":"Distance.html#t:point/0"},{"type":"function","title":"Distance.project/3","doc":"Returns a point `distance` units away in the direction `direction`.\n\nThe direction is measured as radians off of the positive x-axis in the direction of\nthe positive y-axis.  Thus the new coordinates are:\n\n```elixir\nx1 = x0 + distance * cos(direction)\ny1 = y0 + distance * sin(direction)\n```","ref":"Distance.html#project/3"},{"type":"function","title":"Examples - Distance.project/3","doc":"iex> Distance.project({3, 5}, 3 * :math.pi() / 4, 2)\n    {1.585786437626905, 6.414213562373095}","ref":"Distance.html#project/3-examples"},{"type":"function","title":"Distance.segment_distance/3","doc":"Returns the geometric distance from a point `p` and the line segment\nbetween two points `p1` and `p2`.  Note that this is a line segment, not\nan infinite line, so points not between `p1` and `p2` will return the\ndistance to the nearest of the two endpoints.","ref":"Distance.html#segment_distance/3"},{"type":"function","title":"Examples - Distance.segment_distance/3","doc":"iex> Distance.segment_distance({3, 2}, {-2, 1}, {5, 3})\n    0.4120816918460673 # distance between the point {3, 2} and the closest point along line segment ({-2, 1}, {5, 3})\n    iex> Distance.segment_distance({1, -2}, {-2, 2}, {-10, 102})\n    5.0\n    iex> Distance.segment_distance({1, -2}, {-2, 2}, {1, -2})\n    0.0","ref":"Distance.html#segment_distance/3-examples"},{"type":"function","title":"Distance.segment_distance_squared/3","doc":"Similar to `Distance.distance_squared`, this provides much faster comparable\nversion of `Distance.segment_distance`.","ref":"Distance.html#segment_distance_squared/3"},{"type":"function","title":"Examples - Distance.segment_distance_squared/3","doc":"iex> Distance.segment_distance_squared({3, 2}, {-2, 1}, {5, 3})\n    0.16981132075471717\n    iex> Distance.segment_distance_squared({1, -2}, {-2, 2}, {-10, 102})\n    25","ref":"Distance.html#segment_distance_squared/3-examples"},{"type":"function","title":"Distance.segment_segment_distance/4","doc":"Provides the minimum distance between any two points along the given line\nsegments.  In the case where the segements are not disjoint, this will\nalways return `0.0`.","ref":"Distance.html#segment_segment_distance/4"},{"type":"function","title":"Example - Distance.segment_segment_distance/4","doc":"iex> Distance.segment_segment_distance({0, 0}, {1, 1}, {1, 0}, {2, 0})\n    0.7071067811865476\n    iex> Distance.segment_segment_distance({0, 0}, {1, 1}, {1, 1}, {2, 2})\n    0.0","ref":"Distance.html#segment_segment_distance/4-example"},{"type":"function","title":"Distance.segment_segment_distance_squared/4","doc":"Similar to `Distance.distance_squared`, this provides much faster comparable\nversion of `Distance.segment_segment_distance`.","ref":"Distance.html#segment_segment_distance_squared/4"},{"type":"module","title":"Distance.GreatCircle","doc":"Calculate great circle distances (shortest travel distance on the surface of\na spherical Earth) given a two longitude-latitude pairs.  This is an implementation\nof the [Haversine formula](https://en.wikipedia.org/wiki/Haversine_formula)\nand approximates using a spherical (non-ellipsoid) Earth with a\nmean radius of 6,371,008.8 meters derived from the WGS84 datum.\n\nThe function accepts two tuples in the form of `{longitude, latitude}` and\nreturns the distance in meters. It will also accept a List of tuples.","ref":"Distance.GreatCircle.html"},{"type":"type","title":"Distance.GreatCircle.coords/0","doc":"","ref":"Distance.GreatCircle.html#t:coords/0"},{"type":"function","title":"Distance.GreatCircle.distance/1","doc":"Returns the great circle distance in meters along a linestring defined by the\nList of `{longitude, latitude}` pairs.","ref":"Distance.GreatCircle.html#distance/1"},{"type":"function","title":"Examples - Distance.GreatCircle.distance/1","doc":"iex> Distance.GreatCircle.distance([\n    ...>  {-96.796667, 32.775833},\n    ...>  {126.967583, 37.566776},\n    ...>  {151.215158, -33.857406},\n    ...>  {55.274180, 25.197229},\n    ...>  {6.942661, 50.334057},\n    ...>  {-97.635926, 30.134442}])\n    44728827.84910666","ref":"Distance.GreatCircle.html#distance/1-examples"},{"type":"function","title":"Distance.GreatCircle.distance/2","doc":"Returns the great circle distance in meters between two points in the form of\n`{longitude, latitude}`.","ref":"Distance.GreatCircle.html#distance/2"},{"type":"function","title":"Examples - Distance.GreatCircle.distance/2","doc":"iex> Distance.GreatCircle.distance({-105.343, 39.984}, {-105.534, 39.123})\n    97129.22118968463\n    iex> Distance.GreatCircle.distance({-74.00597, 40.71427}, {-70.56656, -33.42628})\n    8251609.780265334","ref":"Distance.GreatCircle.html#distance/2-examples"},{"type":"module","title":"Distance.Vincenty","doc":"Calculate distance per [Vincenty's inverse formula](https://en.wikipedia.org/wiki/Vincenty%27s_formulae)\n(shortest travel distance on the surface of an [oblate spheroid](https://en.wikipedia.org/wiki/Spheroid#Oblate_spheroids) Earth) given two longitude-latitude pairs.\n\nThis method is iterative and more costly than other methods, such as the [great circle](lib/distance/great_circle.ex) method, but also potentially more accurate.\nIt is important to note that [nearly antipodal points](https://en.wikipedia.org/wiki/Vincenty%27s_formulae#Nearly_antipodal_points) can cause convergence issues with this method.\n\nThe function accepts two tuples in the form of `{longitude, latitude}` and\nreturns the distance in meters. It will also accept a List of tuples.","ref":"Distance.Vincenty.html"},{"type":"type","title":"Distance.Vincenty.coords/0","doc":"","ref":"Distance.Vincenty.html#t:coords/0"},{"type":"function","title":"Distance.Vincenty.distance/1","doc":"Returns the distance in meters along a linestring defined by the\nList of `{longitude, latitude}` pairs, per Vincenty's inverse formula.","ref":"Distance.Vincenty.html#distance/1"},{"type":"function","title":"Examples - Distance.Vincenty.distance/1","doc":"iex> Distance.Vincenty.distance([\n    ...>  {-96.796667, 32.775833},\n    ...>  {126.967583, 37.566776},\n    ...>  {151.215158, -33.857406},\n    ...>  {55.274180, 25.197229},\n    ...>  {6.942661, 50.334057},\n    ...>  {-97.635926, 30.134442}])\n    44737835.51457705","ref":"Distance.Vincenty.html#distance/1-examples"},{"type":"function","title":"Distance.Vincenty.distance/2","doc":"Returns the distance in meters between two points in the form of\n`{longitude, latitude}`, per Vincenty's inverse formula.","ref":"Distance.Vincenty.html#distance/2"},{"type":"function","title":"Examples - Distance.Vincenty.distance/2","doc":"iex> Distance.Vincenty.distance({-105.343, 39.984}, {-105.534, 39.123})\n    96992.65430928342\n    iex> Distance.Vincenty.distance({-74.00597, 40.71429}, {-70.56656, -33.42629})\n    8216472.876442492","ref":"Distance.Vincenty.html#distance/2-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}